// src/app/api/sun/route.ts
import { NextResponse } from 'next/server';

export async function GET() {
    const apiKey = process.env.QWEATHER_API_KEY;
    const [longitude, latitude] = [116.3974, 39.9093];
    const today = new Date();

    try {
        // 生成包含今天在内的未来6天日期
        const datePromises = Array.from({ length: 6 }).map((_, i) => {
            const date = new Date(today);
            date.setDate(today.getDate() + i);
            return date;
        });

        const responses = await Promise.all(
            datePromises.map(date => {
                const formattedDate = date.toISOString().split('T')[0].replace(/-/g, '');
                return fetch(
                    `https://devapi.qweather.com/v7/astronomy/sun?` +
                    `location=${longitude},${latitude}&date=${formattedDate}&key=${apiKey}`
                );
            })
        );

        // 增强的错误处理
        const errors = responses.filter(res => !res.ok);
        if (errors.length > 0) {
            throw new Error(`API请求失败: ${errors.map(e => e.statusText).join(', ')}`);
        }

        const sunData = await Promise.all(responses.map(res => res.json()));

        // 数据格式化和验证
        const formattedData = sunData.map((item, index) => {
            const targetDate = new Date(today);
            targetDate.setDate(today.getDate() + index);
            
            return {
                date: targetDate.toISOString().split('T')[0],
                sunrise: safeFormatTime(item.sunrise),
                sunset: safeFormatTime(item.sunset)
            };
        });

        return NextResponse.json(formattedData, {
            headers: {
                'Cache-Control': 'public, s-maxage=3600',
                'CDN-Cache-Control': 'public, s-maxage=7200'
            }
        });

    } catch (error) {
        console.error('日出日落数据获取失败:', error);
        return NextResponse.json(
            { error: "数据获取失败，请稍后重试" },
            { status: 500 }
        );
    }
}

// 健壮的时间格式化方法
function safeFormatTime(timeStr: string) {
    // 直接匹配HH:mm格式
    const directMatch = timeStr.match(/(\d{2}:\d{2})/);
    if (directMatch) return directMatch[1];

    // 处理ISO格式
    try {
        const date = new Date(timeStr);
        return date.toLocaleTimeString('zh-CN', {
            hour: '2-digit',
            minute: '2-digit',
            hour12: false
        });
    } catch {
        // 最终处理非常规格式
        return timeStr.split('T')[1]?.substring(0, 5) || '--:--';
    }
}