// src/components/WeatherSection.tsx
import { FC } from "react";
import { WeatherData } from "../types/magic-mirror";
import CircularProgress from "@mui/material/CircularProgress";

interface WeatherSectionProps {
  data?: WeatherData;
}

const WeatherSection: FC<WeatherSectionProps> = ({ data }) => {
  if (!data) {
    return (
      <div className="absolute top-8 right-0 w-64 flex items-center justify-center h-32">
        <CircularProgress size={24} color="inherit" />
        <span className="ml-2 text-gray-400">天气加载中...</span>
      </div>
    );
  }

  // 获取天气图标
  const getWeatherIcon = (condition?: string) => {
    const iconMap: Record<string, string> = {
      晴: "☀️",
      多云: "⛅",
      阴: "☁️",
      小雨: "🌧️",
      中雨: "🌧️",
      大雨: "⛈️",
      暴雨: "🌧️💦",
    };
    return condition ? iconMap[condition] || "🌤️" : "🌤️";
  };

  return (
    <>
      <div className="absolute top-8 right-0 w-64 space-y-4">
        <div className="grid grid-cols-2 gap-4 text-sm">
          <div className="space-y-1">
            <div className="text-gray-400">风速</div>
            <div className="text-gray-300">
              {data.windSpeed || "--"}km/h {data.windDirection || ""}
            </div>
          </div>
          <div className="space-y-1">
            <div className="text-gray-400">日出/日落</div>
            <div className="text-gray-300">
              {data.sunrise || "--:--"} / {data.sunset || "--:--"}
            </div>
          </div>
        </div>

        <div className="flex items-center gap-4">
          <div className="text-4xl">{getWeatherIcon(data.condition)}</div>
          <div>
            <div className="text-3xl">{data.temp ?? "--"}°C</div>
            <div className="text-gray-400 text-sm">
              体感 {data.feelsLike ?? "--"}°C
            </div>
          </div>
        </div>

        <div className="space-y-2">
          <div className="text-gray-400 text-sm">紫外线指数</div>
          <div className="text-gray-300">{data.uvIndex || "--"}</div>
        </div>
      </div>

      {/* 天气预报模块 */}
      <div className="absolute top-64 right-8 w-72 bg-black/50 backdrop-blur-sm rounded-lg p-4 shadow-lg">
        <div className="text-gray-300 text-sm font-medium mb-3">
          未来5天预报
        </div>
        <div className="space-y-2">
          {data.forecast.slice(0, 5).map((day, index) => (
            <div
              key={day.day || index}
              className="flex justify-between items-center group transition-all duration-200 hover:bg-white/10 px-2 py-1 rounded-md"
              style={{ opacity: 1 - index * 0.15 }}
            >
              {/* 日期 */}
              <div className="text-gray-300 text-sm font-light w-16">
                {day.day || "未知"}
              </div>

              {/* 天气图标
              <div className="text-gray-400 text-lg">
                {getWeatherIcon(day.condition)}
              </div> */}

              {/* 天气图标和名称 */}
              <div className="flex items-center gap-2 w-24">
                <div className="text-gray-400 text-lg">
                  {getWeatherIcon(day.condition)}
                </div>
                <div className="text-gray-300 text-sm font-light">
                  {day.condition || "未知"}
                </div>
              </div>

              {/* 温度范围 */}
              <div className="flex items-center gap-2">
                <span className="text-blue-300 text-sm">
                  {day.low ?? "--"}°
                </span>
                <div className="w-12 h-1 bg-gradient-to-r from-blue-400 to-red-400 rounded-full" />
                <span className="text-red-300 text-sm">
                  {day.high ?? "--"}°
                </span>
              </div>
            </div>
          ))}
        </div>
      </div>



      
    </>
  );
};

export default WeatherSection;
